@@ -8,14 +8,25 @@ url注解
 
 __revision__ = '0.1'
 
-from url_refactor import _Type, _RequestMethod, _M
+__all__ = (
+    'Type',
+    'M',
+    'RequestMethod',
+    'login_required',
+    'get',
+    'post',
+    'url',
+    'files',
+)
+
+from url_refactor import _Type, _RequestMethod
 from url_refactor import _login_required, _get, _post, _url, _files
 
 Type = _Type
-M = _M
 RequestMethod = _RequestMethod
+M = _RequestMethod
 login_required = _login_required
 get = _get
 post = _post
 url = _url
-files = _files
\ No newline at end of file
+files = _files
